Command Line Interface (CLI)
=============================

The CLI allows for installation (:code:`virtue install`) and inspection
(:code:`virtue info`, :code:`virtue list`) of the active
Virtue environment.

See the cli help (:code:`virtue --help`) or the
:ref:`Command Line Interface (CLI) Reference` for more details
on the interface.
